#!/usr/bin/env python

#
# Wiretap SDK tool for creating a generic node.
#

from __future__ import print_function

import getopt
import sys
from libwiretapPythonClientAPI import (
    WireTapClient,
    WireTapServerHandle,
    WireTapNodeHandle
)

def printUsage():

    print(" Usage:")
    print("  -n <parent node ID>")
    print("  -s <source node ID>")
    print("  -d <display name of duplicate node>")
    print("  [-h <host name or IP address> (default = localhost)]")

def main():

    # Check the command line options for correctness.
    try:
        opts, _ = getopt.getopt(sys.argv, "h:n:s:d:")
    except getopt.GetoptError:
        printUsage()
        sys.exit(2)

    # Declare variables (to be set from command line arguments).
    # For hostName, the default "localhost" will work if a Wiretap server
    # is running on your machine.
    #
    hostName = "localhost"
    parentNodeId = ""
    srcNodeId = ""
    displayName = ""

    # Parse command line and set variables just declared.
    #
    for opt, arg in opts:
        if opt == '-h':
            hostName = arg
        elif opt == '-n':
            parentNodeId = arg
        if opt == "-s":
            srcNodeId = arg
        if opt == "-d":
            displayName = arg

    if parentNodeId == "" or srcNodeId == "" or displayName == "":
        printUsage()
        sys.exit(2)

    # Initialize the Wiretap Client API.
    #
    wiretapClient = WireTapClient()
    if not wiretapClient.init():
        raise Exception("Unable to initialize Wiretap client API")

    try:
        # Instantiate a server handle
        #
        server = WireTapServerHandle(hostName)

        # Instantiate the parent node
        #
        parentNode = WireTapNodeHandle(server, parentNodeId)
        srcNode = WireTapNodeHandle(server, srcNodeId)
        newNode = WireTapNodeHandle()

        # Create the node.
        #
        if not parentNode.duplicateNode(srcNode, displayName, newNode):
            raise Exception("Unable to create node: %s" % parentNode.lastError())

        print("Created node '%s'." % newNode.getNodeId().id())

    finally:
        # Must destroy WireTapServerHandle and WireTapNodeHandle before
        # uninitializing the Wiretap Client API.
        #
        parentNode = None
        srcNode = None
        newNode = None
        server = None

if __name__ == '__main__':
    main()
