#!/usr/bin/env python

#
# Wiretap SDK tool for setting the number of frames in a clip node.
#

from __future__ import print_function

import getopt
import sys
from libwiretapPythonClientAPI import (
    WireTapClient,
    WireTapServerHandle,
    WireTapNodeHandle
)

def printUsage():
    print("Usage:\n"
          "-n <node Id>\n"
          "-N <num frames>\n"
          "[-h <hostname>]\n")

def main():

    # Check the command line options for correctness.
    try:
        opts, _ = getopt.getopt(sys.argv, "h:n:N:")
    except getopt.GetoptError:
        printUsage()
        sys.exit(2)

    # Declare variables (to be set from command line arguments).
    # For hostName, the default "localhost" will work if a Wiretap server
    # is running on your machine.
    #
    hostName = "localhost"
    nodeId = ""
    numFrames = 0

    # Parse command line and set variables just declared.
    #
    for opt, arg in opts:
        if opt == '-h':
            hostName = arg
        elif opt == '-n':
            nodeId = arg
        elif opt == '-N':
            numFrames = int(arg)

    if nodeId == "":
        print("Node ID not specified.\n")
        printUsage()
        sys.exit(2)

    # Initialize the Wiretap Client API.
    #
    wiretapClient = WireTapClient()
    if not wiretapClient.init():
        raise Exception("Unable to initialize Wiretap client API")

    try:
        # Instantiate a server handle
        #
        server = WireTapServerHandle(hostName)

        # Instantiate the node and set the number of frames in the clip.
        #
        node = WireTapNodeHandle(server, nodeId)
        if not node.setNumFrames(numFrames):
            raise Exception("Unable to set the number of frames: %s\n" % node.lastError())

        # Display result.
        #
        print(numFrames)

    finally:
        # Must destroy WireTapServerHandle and WireTapNodeHandle before
        # uninitializing the Wiretap Client API.
        #
        node = None
        server = None


if __name__ == '__main__':
    main()
